@@ -36,20 +36,20 @@ class AsyncPublisherClientInterface(AsyncContextManager):
         **attrs: Mapping[str, str],
     ) -> str:
         """
-    Publish a message.
+        Publish a message.
 
-    Args:
-      topic: The topic to publish to. Publishes to new topics may have nontrivial startup latency.
-      data: The bytestring payload of the message
-      ordering_key: The key to enforce ordering on, or "" for no ordering.
-      **attrs: Additional attributes to send.
+        Args:
+          topic: The topic to publish to. Publishes to new topics may have nontrivial startup latency.
+          data: The bytestring payload of the message
+          ordering_key: The key to enforce ordering on, or "" for no ordering.
+          **attrs: Additional attributes to send.
 
-    Returns:
-      An ack id, which can be decoded using MessageMetadata.decode.
+        Returns:
+          An ack id, which can be decoded using MessageMetadata.decode.
 
-    Raises:
-      GoogleApiCallError: On a permanent failure.
-    """
+        Raises:
+          GoogleApiCallError: On a permanent failure.
+        """
 
 
 class PublisherClientInterface(ContextManager):
@@ -67,20 +67,20 @@ class PublisherClientInterface(ContextManager):
         data: bytes,
         ordering_key: str = "",
         **attrs: Mapping[str, str],
-    ) -> Future:
+    ) -> "Future[str]":
         """
-    Publish a message.
+        Publish a message.
 
-    Args:
-      topic: The topic to publish to. Publishes to new topics may have nontrivial startup latency.
-      data: The bytestring payload of the message
-      ordering_key: The key to enforce ordering on, or "" for no ordering.
-      **attrs: Additional attributes to send.
+        Args:
+          topic: The topic to publish to. Publishes to new topics may have nontrivial startup latency.
+          data: The bytestring payload of the message
+          ordering_key: The key to enforce ordering on, or "" for no ordering.
+          **attrs: Additional attributes to send.
 
-    Returns:
-      A future completed with an ack id of type str, which can be decoded using
-      MessageMetadata.decode.
+        Returns:
+          A future completed with an ack id of type str, which can be decoded using
+          MessageMetadata.decode.
 
-    Raises:
-      GoogleApiCallError: On a permanent failure.
-    """
+        Raises:
+          GoogleApiCallError: On a permanent failure.
+        """
